@@ -13,18 +13,21 @@
 #' \donttest{
 #' # first, create the yml file using use_auth0() function
 #'
-#' # ui.R file
-#' library(shiny)
-#' library(auth0)
-#' auth0_ui(fluidPage(logoutButton()))
+#' if (interactive()) {
 #'
-#' # server.R file
-#' library(auth0)
-#' auth0_server(function(input, output, session) {})
+#'   # ui.R file
+#'   library(shiny)
+#'   library(auth0)
+#'   auth0_ui(fluidPage(logoutButton()))
 #'
-#' # console
-#' options(shiny.port = 8080)
-#' shiny::runApp()
+#'   # server.R file
+#'   library(auth0)
+#'   auth0_server(function(input, output, session) {})
+#'
+#'   # console
+#'   options(shiny.port = 8080)
+#'   shiny::runApp()
+#' }
 #'
 #' }
 #' @export
@@ -35,7 +38,7 @@ auth0_ui <- function(ui, info) {
     if (!verify) {
       if (grepl("error=unauthorized", req$QUERY_STRING)) {
         redirect <- sprintf("location.replace(\"%s\");", logout_url())
-        htmltools::tags$script(htmltools::HTML(redirect))
+        shiny::tags$script(shiny::HTML(redirect))
       } else {
 
         params <- shiny::parseQueryString(req$QUERY_STRING)
@@ -56,11 +59,13 @@ auth0_ui <- function(ui, info) {
         }
         redirect_uri <<- redirect_uri
 
+        query_extra <- if(is.null(info$audience)) list() else list(audience=info$audience)
         url <- httr::oauth2.0_authorize_url(
-          info$api, info$app(redirect_uri), scope = info$scope, state = info$state
+          info$api, info$app(redirect_uri), scope = info$scope, state = info$state,
+          query_extra=query_extra
         )
         redirect <- sprintf("location.replace(\"%s\");", url)
-        htmltools::tags$script(htmltools::HTML(redirect))
+        shiny::tags$script(shiny::HTML(redirect))
       }
     } else {
       if (is.function(ui)) {
@@ -155,33 +160,36 @@ shinyAuth0App <- function(ui, server, config_file = NULL) {
 #' # simple UI with action button
 #' # AFTER auth0 0.1.2
 #'
-#' library(shiny)
-#' library(auth0)
+#' if (interactive()) {
+#'   library(shiny)
+#'   library(auth0)
 #'
-#' ui <- fluidPage(logoutButton())
-#' server <- function(input, output, session) {}
-#' shinyAppAuth0(ui, server, config_file)
+#'   ui <- fluidPage(logoutButton())
+#'   server <- function(input, output, session) {}
+#'   config_file <- system.file("simple/_auth0.yml", package = "auth0")
+#'   shinyAppAuth0(ui, server, config_file)
 #'
-#' # simple UI with action button
-#' # BEFORE auth0 0.1.2
+#'   # simple UI with action button
+#'   # BEFORE auth0 0.1.2
 #'
-#' library(shiny)
-#' library(auth0)
-#' library(shinyjs)
+#'   library(shiny)
+#'   library(auth0)
+#'   library(shinyjs)
 #'
-#' # note that you must include shinyjs::useShinyjs() for this to work
-#' ui <- fluidPage(shinyjs::useShinyjs(), actionButton("logout_auth0", "Logout"))
+#'   # note that you must include shinyjs::useShinyjs() for this to work
+#'   ui <- fluidPage(shinyjs::useShinyjs(), actionButton("logout_auth0", "Logout"))
 #'
-#' # server with one observer that logouts
-#' server <- function(input, output, session) {
-#'   observeEvent(input$logout_auth0, {
-#'     # javascript code redirecting to correct url
-#'     js <- auth0_logout_url()
-#'     shinyjs::runjs(js)
-#'   })
+#'   # server with one observer that logouts
+#'   server <- function(input, output, session) {
+#'     observeEvent(input$logout_auth0, {
+#'       # javascript code redirecting to correct url
+#'       js <- auth0_logout_url()
+#'       shinyjs::runjs(js)
+#'     })
+#'   }
+#'   shinyAuth0App(ui, server, config_file)
 #' }
 #'
-#' shinyAuth0App(ui, server, config_file = config_file)
 #' }
 #'
 #'
